import { Socket } from 'node:net';
import proxyAddr from 'proxy-addr';
import { IncomingMessage, ServerResponse } from 'node:http';
import { EncryptionFactory } from '@adonisjs/encryption/factories';
import { Request } from '../src/request.js';
import { QsParserFactory } from './qs_parser_factory.js';
export class RequestFactory {
    #parameters = {};
    #getConfig() {
        return {
            allowMethodSpoofing: false,
            trustProxy: proxyAddr.compile('loopback'),
            subdomainOffset: 2,
            generateRequestId: false,
            ...this.#parameters.config,
        };
    }
    #createRequest() {
        const req = this.#parameters.req || new IncomingMessage(new Socket());
        if (this.#parameters.url) {
            req.url = this.#parameters.url;
        }
        if (this.#parameters.method) {
            req.method = this.#parameters.method;
        }
        return req;
    }
    #createResponse(req) {
        return this.#parameters.res || new ServerResponse(req);
    }
    #createEncryption() {
        return this.#parameters.encryption || new EncryptionFactory().create();
    }
    merge(params) {
        Object.assign(this.#parameters, params);
        return this;
    }
    create() {
        const req = this.#createRequest();
        return new Request(req, this.#createResponse(req), this.#createEncryption(), this.#getConfig(), new QsParserFactory().create());
    }
}
