import { Socket } from 'node:net';
import { IncomingMessage, ServerResponse } from 'node:http';
import { EncryptionFactory } from '@adonisjs/encryption/factories';
import { RouterFactory } from './router.js';
import { Response } from '../src/response.js';
import { QsParserFactory } from './qs_parser_factory.js';
export class ResponseFactory {
    #parameters = {};
    #getConfig() {
        return {
            etag: false,
            jsonpCallbackName: 'callback',
            cookie: {
                maxAge: 90,
                path: '/',
                httpOnly: true,
                sameSite: false,
                secure: false,
            },
            ...this.#parameters.config,
        };
    }
    #createRequest() {
        return this.#parameters.req || new IncomingMessage(new Socket());
    }
    #createRouter() {
        return this.#parameters.router || new RouterFactory().create();
    }
    #createResponse(req) {
        return this.#parameters.res || new ServerResponse(req);
    }
    #createEncryption() {
        return this.#parameters.encryption || new EncryptionFactory().create();
    }
    merge(params) {
        Object.assign(this.#parameters, params);
        return this;
    }
    create() {
        const req = this.#createRequest();
        return new Response(req, this.#createResponse(req), this.#createEncryption(), this.#getConfig(), this.#createRouter(), new QsParserFactory().create());
    }
}
