import { Logger } from '@adonisjs/logger';
import { Emitter } from '@adonisjs/events';
import { AppFactory } from '@adonisjs/application/factories';
import { EncryptionFactory } from '@adonisjs/encryption/factories';
import { Server } from '../src/server/main.js';
import { defineConfig } from '../src/define_config.js';
export class ServerFactory {
    #parameters = {};
    #getEmitter() {
        return this.#parameters.emitter || new Emitter(this.#getApp());
    }
    #getLogger() {
        return this.#parameters.logger || new Logger({ enabled: false });
    }
    #getConfig() {
        return defineConfig(this.#parameters.config || {});
    }
    #getApp() {
        return (this.#parameters.app || new AppFactory().create(new URL('./app/', import.meta.url), () => { }));
    }
    #createEncryption() {
        return this.#parameters.encryption || new EncryptionFactory().create();
    }
    merge(params) {
        Object.assign(this.#parameters, params);
        return this;
    }
    create() {
        return new Server(this.#getApp(), this.#createEncryption(), this.#getEmitter(), this.#getLogger(), this.#getConfig());
    }
}
