import Macroable from '@poppinss/macroable';
import { BriskRoute } from './brisk.js';
import { RouteResource } from './resource.js';
export class RouteGroup extends Macroable {
    routes;
    #middleware = [];
    constructor(routes) {
        super();
        this.routes = routes;
    }
    #shareMiddlewareStackWithRoutes(route) {
        if (route instanceof RouteGroup) {
            route.routes.forEach((child) => this.#shareMiddlewareStackWithRoutes(child));
            return;
        }
        if (route instanceof RouteResource) {
            route.routes.forEach((child) => child.getMiddleware().unshift(this.#middleware));
            return;
        }
        if (route instanceof BriskRoute) {
            route.route.getMiddleware().unshift(this.#middleware);
            return;
        }
        route.getMiddleware().unshift(this.#middleware);
    }
    #updateRouteName(route, name) {
        if (route instanceof RouteGroup) {
            route.routes.forEach((child) => this.#updateRouteName(child, name));
            return;
        }
        if (route instanceof RouteResource) {
            route.routes.forEach((child) => child.as(name, true));
            return;
        }
        if (route instanceof BriskRoute) {
            route.route.as(name, true);
            return;
        }
        route.as(name, true);
    }
    #setRoutePrefix(route, prefix) {
        if (route instanceof RouteGroup) {
            route.routes.forEach((child) => this.#setRoutePrefix(child, prefix));
            return;
        }
        if (route instanceof RouteResource) {
            route.routes.forEach((child) => child.prefix(prefix));
            return;
        }
        if (route instanceof BriskRoute) {
            route.route.prefix(prefix);
            return;
        }
        route.prefix(prefix);
    }
    #updateRouteDomain(route, domain) {
        if (route instanceof RouteGroup) {
            route.routes.forEach((child) => this.#updateRouteDomain(child, domain));
            return;
        }
        if (route instanceof RouteResource) {
            route.routes.forEach((child) => child.domain(domain));
            return;
        }
        if (route instanceof BriskRoute) {
            route.route.domain(domain, false);
            return;
        }
        route.domain(domain, false);
    }
    #updateRouteMatchers(route, param, matcher) {
        if (route instanceof RouteGroup) {
            route.routes.forEach((child) => this.#updateRouteMatchers(child, param, matcher));
            return;
        }
        if (route instanceof RouteResource) {
            route.routes.forEach((child) => child.where(param, matcher));
            return;
        }
        if (route instanceof BriskRoute) {
            route.route.where(param, matcher);
            return;
        }
        route.where(param, matcher);
    }
    where(param, matcher) {
        this.routes.forEach((route) => this.#updateRouteMatchers(route, param, matcher));
        return this;
    }
    prefix(prefix) {
        this.routes.forEach((route) => this.#setRoutePrefix(route, prefix));
        return this;
    }
    domain(domain) {
        this.routes.forEach((route) => this.#updateRouteDomain(route, domain));
        return this;
    }
    as(name) {
        this.routes.forEach((route) => this.#updateRouteName(route, name));
        return this;
    }
    use(middleware) {
        if (!this.#middleware.length) {
            this.routes.forEach((route) => this.#shareMiddlewareStackWithRoutes(route));
        }
        if (Array.isArray(middleware)) {
            for (let one of middleware) {
                this.#middleware.push(one);
            }
        }
        else {
            this.#middleware.push(middleware);
        }
        return this;
    }
    middleware(middleware) {
        return this.use(middleware);
    }
}
