/// <reference types="node" resolution-mode="require"/>
/// <reference types="node" resolution-mode="require"/>
import { Emitter } from '@adonisjs/events';
import type { Logger } from '@adonisjs/logger';
import type { Encryption } from '@adonisjs/encryption';
import type { Server as HttpsServer } from 'node:https';
import type { Application } from '@adonisjs/application';
import { ContainerResolver } from '@adonisjs/fold';
import type { ServerResponse, IncomingMessage, Server as HttpServer } from 'node:http';
import type { LazyImport } from '../types/base.js';
import type { MiddlewareAsClass } from '../types/middleware.js';
import type { ServerConfig, ErrorHandlerAsAClass, TestingMiddlewarePipeline } from '../types/server.js';
import { Request } from '../request.js';
import { Response } from '../response.js';
import { Router } from '../router/main.js';
import { HttpContext } from '../http_context/main.js';
export declare class Server {
    #private;
    get usingAsyncLocalStorage(): boolean;
    constructor(app: Application<any>, encryption: Encryption, emitter: Emitter<any>, logger: Logger, config: ServerConfig);
    pipeline(middleware: MiddlewareAsClass[]): TestingMiddlewarePipeline;
    use(middleware: LazyImport<MiddlewareAsClass>[]): this;
    errorHandler(handler: LazyImport<ErrorHandlerAsAClass>): this;
    boot(): Promise<void>;
    setNodeServer(server: HttpServer | HttpsServer): void;
    getNodeServer(): HttpServer<typeof IncomingMessage, typeof ServerResponse> | HttpsServer<typeof IncomingMessage, typeof ServerResponse> | undefined;
    getRouter(): Router;
    createRequest(req: IncomingMessage, res: ServerResponse): Request;
    createResponse(req: IncomingMessage, res: ServerResponse): Response;
    createHttpContext(request: Request, response: Response, resolver: ContainerResolver<any>): HttpContext;
    handle(req: IncomingMessage, res: ServerResponse): Promise<any>;
}
